Gmls
====

GitHub Markdown Local Server.

I read great markdown wikis on github offline with it :).

Install
-------

```bash
$ [sudo] pip install gmls
```

Usage
------

```bash
Usage:
  gmls [-p PORT|-f|-h|-v]

Options:
  -p PORT           server port [default: 5000]
  -f --freeze       freeze site to static htmls
  -h --help         show this message
  -v --version      show version
```

License
-------

MIT. Copyright hit9.
